## # # # # # # # # # # # # # # # # # # # # # # # #
##
## Project: Hydrophobins
##
## Script name: 001_Data_analysis.R
##
## Purpose of script: Quantify differences between protein intensities in 
##                    hydrophobin samples
##
## Author: Florian Weiland
##
## Date Created: 27-Jan-2022
##
## # # # # # # # # # # # # # # # # # # # # # # # #

## Libraries ----

library(stringr)
library(vsn)
library(matrixStats)

## Read in data ----

data <- read.csv(
  "./Data/evidence.txt",
  sep = "\t"
)

## Extract unique hydrophobin "XP_006964181.1" peptides

hyd <- grep("XP_006964181.1", data$Leading.razor.protein)
hyd.df <- data[hyd, ]

hyd.clean <- hyd.df[order(hyd.df$PEP), ]
hyd.clean <- hyd.clean[!duplicated(hyd.clean$Modified.sequence), ]

## Get sequence position

data.pep <- read.csv(
  "./Data/peptides.txt",
  sep = "\t"
)

for (i in 1:nrow(hyd.clean)){

  rows.temp <- which(data.pep$id == hyd.clean$Peptide.ID[i])
  
  hyd.clean[i, "Start.Position"] <- data.pep[rows.temp, "Start.position"]
  hyd.clean[i, "End.Position"]   <- data.pep[rows.temp, "End.position"]
  
}

results.cols <- c(
  "Sequence",
  "Start.Position",
  "End.Position",
  "Modifications",
  "Modified.sequence",
  "Ammonia.loss..N..Probabilities",
  "Deamidation..N..Probabilities",
  "Leading.razor.protein",
  "PEP",
  "m.z",
  "Charge",
  "Mass.error..ppm."
)

results.df <- hyd.clean[, results.cols]

write.csv(results.df, "./Output_R/Results.csv", row.names = FALSE)  


## Quant ----
## Clean up data and merge

rem.rev <- which(data$Reverse == "+")
rem.pep <- which(data$PEP > 0.05)
rem.con <- which(data$Potential.contaminant == "+")

data.clean <- data[-c(rem.rev, rem.pep, rem.con), ]

exp <- unique(data.clean$Experiment)

sh1.r <- which(data.clean$Experiment == "SH1")
sh2.r <- which(data.clean$Experiment == "SH2")
sh3.r <- which(data.clean$Experiment == "SH3")
sh4.r <- which(data.clean$Experiment == "SH4")

cols <- c("Sequence", "Modified.sequence", "Leading.razor.protein", "Intensity", "Experiment")

data.sh1 <- data.clean[sh1.r, cols]
data.sh2 <- data.clean[sh2.r, cols]
data.sh3 <- data.clean[sh3.r, cols]
data.sh4 <- data.clean[sh4.r, cols]

data.12 <- merge(data.sh1, data.sh2, by = "Modified.sequence", all = TRUE)
data.34 <- merge(data.sh3, data.sh4, by = "Modified.sequence", all = TRUE)

data.m <- merge(data.12, data.34, by = "Modified.sequence", all = TRUE)

## Clean up data.m and restructure

seq.cols   <- grep("^Sequence", colnames(data.m))
mod.cols   <- grep("^Modified", colnames(data.m))
razor.cols <- grep("^Leading", colnames(data.m))
int.cols   <- grep("^Intensity", colnames(data.m))

data.final <- data.frame()

for (a in 1:nrow(data.m)) {
  
  seq <- unique(unlist(data.m[a, seq.cols]))
  seq <- seq[!is.na(seq)]
  
  mod <- unique(unlist(data.m[a, mod.cols]))
  mod <- mod[!is.na(mod)]
  
  razor <- unique(unlist(data.m[a, razor.cols]))
  razor <- razor[!is.na(razor)]

  int <- data.m[a, int.cols]
  
  int.sh1 <- int[, which(colnames(int) == "Intensity.x.x")]
  int.sh2 <- int[, which(colnames(int) == "Intensity.y.x")]
  int.sh3 <- int[, which(colnames(int) == "Intensity.x.y")]
  int.sh4 <- int[, which(colnames(int) == "Intensity.y.y")]
  
  data.final[a, "Sequence"] <- seq
  data.final[a, "Modified.sequence"] <- mod
  data.final[a, "Leading.razor.protein"] <-razor
  data.final[a, "Intensity.SH1"] <- int.sh1
  data.final[a, "Intensity.SH2"] <- int.sh2
  data.final[a, "Intensity.SH3"] <- int.sh3
  data.final[a, "Intensity.SH4"] <- int.sh4
}

## Averaging (median) of unique peptide intensities ----

uni.pep <- unique(data.final$Modified.sequence)

data.av <- data.frame()

for (cur.pep in uni.pep) {
  
  data.temp <- data.final[which(data.final$Modified.sequence == cur.pep), ]
  data.int <- colMedians(as.matrix(data.temp[, grep("^Intensity", colnames(data.temp))]), na.rm = TRUE)
  
  data.int[is.nan(data.int)] <- NA
  
  data.av.temp <- cbind(data.temp[1, 1:3], t(data.int))
  colnames(data.av.temp)[4:7] <- colnames(data.temp)[4:7]
  
  data.av <- rbind(data.av, data.av.temp)
  
}

## Normalization by VSN ----

data.vsn <- as.matrix(data.av[, grep("Intensity", colnames(data.av))])
vsn.model <- vsn2(data.vsn)

data.trans <- predict(vsn.model, newdata = data.vsn)
colnames(data.trans) <- paste0("VSN.", colnames(data.trans))

data.final <- cbind(data.av, data.trans)

data.hyd <- data.final[grep("XP_006964181.1", data.final$Leading.razor.protein), ]

## Statistical testing ----

temp.sh1 <- data.hyd[, "VSN.Intensity.SH1"]
temp.sh2 <- data.hyd[, "VSN.Intensity.SH2"]
temp.sh3 <- data.hyd[, "VSN.Intensity.SH3"]
temp.sh4 <- data.hyd[, "VSN.Intensity.SH4"]

## Only peptides which are detected in both samples

rows.sh1.sh2 <- intersect(which(!is.na(temp.sh1)), which(!is.na(temp.sh2)))
rows.sh1.sh3 <- intersect(which(!is.na(temp.sh1)), which(!is.na(temp.sh3)))
rows.sh1.sh4 <- intersect(which(!is.na(temp.sh1)), which(!is.na(temp.sh4)))

rows.sh2.sh3 <- intersect(which(!is.na(temp.sh2)), which(!is.na(temp.sh3)))
rows.sh2.sh4 <- intersect(which(!is.na(temp.sh2)), which(!is.na(temp.sh4)))

rows.sh3.sh4 <- intersect(which(!is.na(temp.sh3)), which(!is.na(temp.sh4)))

## t-tests

sh1.vs.sh2 <- round(t.test(temp.sh1[rows.sh1.sh2], temp.sh2[rows.sh1.sh2], paired = TRUE)$p.value, 4)
sh1.vs.sh3 <- round(t.test(temp.sh1[rows.sh1.sh3], temp.sh3[rows.sh1.sh3], paired = TRUE)$p.value, 4)
sh1.vs.sh4 <- round(t.test(temp.sh1[rows.sh1.sh4], temp.sh4[rows.sh1.sh4], paired = TRUE)$p.value, 4)

sh2.vs.sh3 <- round(t.test(temp.sh2[rows.sh2.sh3], temp.sh3[rows.sh2.sh3], paired = TRUE)$p.value, 4)
sh2.vs.sh4 <- round(t.test(temp.sh2[rows.sh2.sh4], temp.sh4[rows.sh2.sh4], paired = TRUE)$p.value, 4)

sh3.vs.sh4 <- round(t.test(temp.sh3[rows.sh3.sh4], temp.sh4[rows.sh3.sh4], paired = TRUE)$p.value, 4)

## Regulation factors of samples with p-value < 0.05

rf.SH1.vs.SH2 <- round(2^mean(temp.sh2[rows.sh1.sh2]) / 2^mean(temp.sh1[rows.sh1.sh2]), 2)
rf.SH2.vs.SH4 <- round(2^mean(temp.sh2[rows.sh2.sh4]) / 2^mean(temp.sh4[rows.sh2.sh4]), 2)

## Build results dataframe ----

results.df <- data.frame(
  
  Protein = "XP_006964181.1hydrophobin[TrichodermareeseiQM6a]",
  
  p.Value.SH1.vs.SH2 = sh1.vs.sh2,
  p.Value.SH1.vs.SH3 = sh1.vs.sh3,
  p.Value.SH1.vs.SH4 = sh1.vs.sh4,
  
  p.Value.SH2.vs.SH3 = sh2.vs.sh3,
  p.Value.SH2.vs.SH4 = sh2.vs.sh4,
  
  p.Value.SH3.vs.SH4 = sh3.vs.sh4,
  
  Regulation.Factor.SH1.vs.SH.2 = rf.SH1.vs.SH2,
  Regulation.Factor.SH2.vs.SH.4 = rf.SH2.vs.SH4
)

write.csv(
  data.hyd,
  "./Output_R/Data_Hydrophobins.csv"
)

write.csv(
  results.df,
  "./Output_R/Statistics_Hydrophobins.csv"
)

## Session Info ----

# sink("Text_File_S1_Session_Info.txt")
# sessionInfo()
# sink()
